@@ -12,7 +12,6 @@ import {
   OPEN_PROJECT_CONFIGURATOR,
   SET_PROJECT_PROPERTIES,
   INIT_CATALOG,
-  SAVE_SCREENSHOT
 } from '../constants';
 
 export function loadProject(sceneJSON) {
@@ -97,9 +96,3 @@ export function initCatalog(catalog) {
     catalog
   }
 }
-
-export function saveScreenshot() {
-  return {
-    type: SAVE_SCREENSHOT
-  };
-}
