@@ -102,7 +102,7 @@ export default function Viewer2D({state, width, height},
 
     switch (mode) {
       case constants.MODE_DRAWING_LINE:
-        linesActions.updateDrawingLine(x, y);
+        linesActions.updateDrawingLine(x, y, !event.getModifierState("Alt"));
         event.stopPropagation();
         break;
 
@@ -122,12 +122,12 @@ export default function Viewer2D({state, width, height},
         break;
 
       case constants.MODE_DRAGGING_LINE:
-        linesActions.updateDraggingLine(x, y);
+        linesActions.updateDraggingLine(x, y, !event.getModifierState("Alt"));
         event.stopPropagation();
         break;
 
       case constants.MODE_DRAGGING_VERTEX:
-        verticesActions.updateDraggingVertex(x, y);
+        verticesActions.updateDraggingVertex(x, y, !event.getModifierState("Alt"));
         event.stopPropagation();
         break;
 
@@ -155,12 +155,12 @@ export default function Viewer2D({state, width, height},
 
         switch (elementData ? elementData.prototype : 'none') {
           case 'lines':
-            linesActions.beginDraggingLine(elementData.layer, elementData.id, x, y);
+            linesActions.beginDraggingLine(elementData.layer, elementData.id, x, y, !event.getModifierState("Alt"));
             event.stopPropagation();
             break;
 
           case 'vertices':
-            verticesActions.beginDraggingVertex(elementData.layer, elementData.id, x, y);
+            verticesActions.beginDraggingVertex(elementData.layer, elementData.id, x, y, !event.getModifierState("Alt"));
             event.stopPropagation();
             break;
 
@@ -221,12 +221,12 @@ export default function Viewer2D({state, width, height},
         break;
 
       case constants.MODE_WAITING_DRAWING_LINE:
-        linesActions.beginDrawingLine(layerID, x, y);
+        linesActions.beginDrawingLine(layerID, x, y, !event.getModifierState("Alt"));
         event.stopPropagation();
         break;
 
       case constants.MODE_DRAWING_LINE:
-        linesActions.endDrawingLine(x, y);
+        linesActions.endDrawingLine(x, y, !event.getModifierState("Alt"));
         event.stopPropagation();
         break;
 
@@ -241,12 +241,12 @@ export default function Viewer2D({state, width, height},
         break;
 
       case constants.MODE_DRAGGING_LINE:
-        linesActions.endDraggingLine(x, y);
+        linesActions.endDraggingLine(x, y, !event.getModifierState("Alt"));
         event.stopPropagation();
         break;
 
       case constants.MODE_DRAGGING_VERTEX:
-        verticesActions.endDraggingVertex(x, y);
+        verticesActions.endDraggingVertex(x, y, !event.getModifierState("Alt"));
         event.stopPropagation();
         break;
 
