@@ -177,8 +177,12 @@ function endDraggingHole(state, x, y) {
 function selectHole(state, layerID, holeID) {
   let scene = state.scene;
 
+  scene = scene.merge({
+    layers: scene.layers.map(unselectAll),
+    selectedLayer: layerID
+  });
+
   scene = scene.updateIn(['layers', layerID], layer => layer.withMutations(layer => {
-    unselectAll(layer);
     select(layer, 'holes', holeID);
   }));
 
